#!/bin/bash
set -x
HighTemp=282
LowTemp=170
###
# 初期設定
#
LogFile=`dirname $0`
LogFile="${LogFile}/BMP085.log"
LogFile="/tmp/BMP085.log"
#echo $LogFile

LockFile=`dirname $0`
LockFile="${LockFile}/AirCon.lock"
#echo $LockFile

###
# 起動パラメータのチェック
#
# Gpio1:エアコン制御のためのGPIOポート
# Gpio2:ボタン読み取りのためのGPIOポート
#
if [ $# -eq 0 ]; then
	Gpio1=22
        Gpio2=11
fi
if [ $# -eq 1 ]; then
	Gpio1=$1
        Gpio2=25
fi
if [ $# -eq 2 ]; then
	Gpio1=$1
        Gpio2=$2
fi

###
# Gpio2からボタンの状態を取得
#
ProgName=`dirname $0`
ProgName="${ProgName}/button ${Gpio2}"
Record="ProgName=${ProgName}"
#echo ${Record} >> $LogFile
AutoMode=`sudo $ProgName`

# AutoMode=0:自動的にエアコン制御しない
# AutoMode=1:自動的にエアコン制御する
Record=`date +"%Y/%m/%d,%T"`
Record=${Record},"AutoMode=${AutoMode}"
echo ${Record} >> $LogFile

###
# リモコン制御プログラム
#
ProgName=`dirname $0`
ProgName="${ProgName}/led ${Gpio1} 1"
#echo ${ProgName}

###
# 自動運転ではないのでエアコンを停止
#
if [ $AutoMode -eq 0 ]; then
    if [ -f $LockFile ]; then
        sudo $ProgName
	irsend SEND_ONCE OCR05 OFF
        rm $LockFile
    fi
    exit
fi

###
# BMP085から温度を取得
#
ProgName=`dirname $0`
ProgName="${ProgName}/readBMP085 -T"
Temp=`sudo $ProgName`

# Temp=BMP085から読み取った温度(10倍値)
#echo $Temp
if [ $Temp -gt $HighTemp ]; then
###
# 室温が高いのでエアコンを開始(冷房運転)
#
    Switch="ON"
    if [ ! -f $LockFile ]; then
        sudo $ProgName
	irsend SEND_ONCE OCR05 ON
        touch $LockFile
    fi
fi

if [ $Temp -le $HighTemp -a $Temp -ge $LowTemp ]; then
###
# エアコンを停止
#
    Switch="OFF"
    if [ -f $LockFile ]; then
        sudo $ProgName
	irsend SEND_ONCE OCR05 OFF
        rm $LockFile
    fi
fi

if [ $Temp -lt $LowTemp ]; then
###
# 室温が低いのでエアコンを開始(暖房運転)
#
    Switch="ON"
    if [ ! -f $LockFile ]; then
        sudo $ProgName
	irsend SEND_ONCE OCR05 ON
        touch $LockFile
    fi
fi


###
# ログを記録
#
#Record=`date +"%Y/%m/%d,%I:%M:%S"`
Record=`date +"%Y/%m/%d,%T"`
Record="${Record},`echo ${Temp} | cut -c 1-2`.`echo ${Temp} | cut -c 3`"
Record="${Record},${Switch}"
#echo "Record=${Record}"
echo ${Record} >> $LogFile
